// graphics libraries
#include "config.h"
// serial stuff
#include <stdio.h>
#include <stdlib.h>
// threading library
#define	SYS_FREQ 40000000 // 40 MHz change the frequency of the clock
// radio library
#include "nrf24l01.h"
#include "pt_cornell_TFT.h"

/*
 * This code will send a message that can be detected by another
 * radio. It can be helpful for testing two radios can actually work.
 */

// set up the radio
void radioSetup() {
    nrf_setup(); // initializing function  
    nrf_set_rf_ch(0x64); // freq = 2.5 GHz  2400+ch(MHz)
	nrf_set_arc(0x07);   // 7 restransmits (0-15 times)
	nrf_set_ard(0x00);   // 250 us between retransmission 250+x*250 us
	nrf_en_aa(0);        // enable autoack on pipe0
	nrf_set_pw(1,0);     // set the payload width to be 1 byte (1-32 bytes, 0-5 pipe)

	nrf_set_address_width(3);   // set the address width 5 bytes(3-5)

	// tx address and the pipe 0 rx address must be the same for autoack mode
	nrf_set_rx_addr(0, 0xAABBCC, 3);  // set pipe 0, receiver address to be 3 bytes
	nrf_set_tx_addr(0xAABBCC);        // set tx address
}

void main(void) {
    INTEnableSystemMultiVectoredInt();
    radioSetup(); // setup the radio for this program      
    mINT1ClearIntFlag();
    
    // === Keypad Thread =============================================
    // connections:
    // A0 -- row 1 -- thru 300 ohm resistor -- avoid short when two buttons pushed
    // A3 -- row 2 -- thru 300 ohm resistor

    // B7  -- col 1 -- 10k pulldown resistor -- avoid open circuit input when no button pushed
    // B13 -- col 2 -- 10k pulldown resistor
    // 0x01 for row 1 ; 0x08 for row 2;
    // 0x80 for col 1 ; 0x2000 for col 2
    // left-top    row1col1 0x81;   right-top    row2col1 0x88;
    // left-bottom row1col2 0x2001; right-bottom row2col2 0x2008;
    int keypad, i, pattern;  
    int keytable[4]={0x81, 0x88, 0x2008, 0x2001};
    // init the keypad pins A0,A3 and B7,B13
    // PortA ports as digital outputs
    mPORTASetPinsDigitalOut(BIT_0 | BIT_3);    //Set port as output
    // PortB as inputs
    mPORTBSetPinsDigitalIn(BIT_7 | BIT_13); 

    char message[4] = {0,1,2,3}; // Byte to be transmitted
    
    while(1)
    {      
        // read each row sequentially
        mPORTAClearBits(BIT_0 | BIT_3);
        pattern = 1; 
        mPORTASetBits(pattern);
 
        for (i=0; i<4; i++) {
            keypad  = mPORTBReadBits(BIT_7 | BIT_13);
            if(keypad!=0) {keypad |= pattern ; break;}
            mPORTAClearBits(pattern);
            pattern <<= 1;
            mPORTASetBits(pattern);
        }

        // search for keycode
        if (keypad > 0){ // then button is pushed
                if (keypad == 0x81) {         // 0
                    while(!nrf_send_payload(&message[0],1));
                    
                }
                else if( keypad == 0x88 ){    // 1
                    while(!nrf_send_payload(&message[1],1));
                    
                }
                else if( keypad == 0x2008 ){  // 2
                    while(!nrf_send_payload(&message[2],1));
                   
                }
                else if( keypad == 0x2001 ){  // 3
                    while(!nrf_send_payload(&message[3],1));
                    
                } 
        }
        else i = -1; // no button pushed
        
        nrf_delay_ms(300); // button debounce time buffer

    }      
   
} // main

// === end  ======================================================